All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [2.0.2] - 2022-11-21
### Removed
- Old tests & docs.

### Added
- `requirementx.txt` containing two packages: **requests**, **packaging**.

### Changed
- Apply modern linters rules.
- `pyzabbix.api` replaced with one from [lukecyca/pyzabbix](https://github.com/lukecyca/pyzabbix) distribution & adjusted according to my needs.

## [1.2.4]
### Changed
- `setup.py` adjusted for PyPi.

### Added
- `README` example of session reusage.

## [1.2.0] - 2018-08-20
### Added
- `api` allow session reusage.
